@@ -1,25 +1,28 @@
-from twilio.rest.resources import InstanceResource, ListResource
-from twilio.rest.resources.applications import Applications
-from twilio.rest.resources.notifications import Notifications
-from twilio.rest.resources.recordings import Transcriptions, Recordings
-from twilio.rest.resources.calls import Calls
-from twilio.rest.resources.sms_messages import Sms
-from twilio.rest.resources.caller_ids import CallerIds
-from twilio.rest.resources.phone_numbers import PhoneNumbers
-from twilio.rest.resources.conferences import Conferences
-from twilio.rest.resources.connect_apps import (
-    ConnectApps, AuthorizedConnectApps
-)
-from twilio.rest.resources.queues import Queues
-from twilio.rest.resources.usage import UsageRecords, UsageTriggers
+from . import InstanceResource, ListResource
+from .applications import Applications
+from .notifications import Notifications
+from .recordings import Transcriptions, Recordings
+from .calls import Calls
+from .sms_messages import Sms
+from .caller_ids import CallerIds
+from .phone_numbers import PhoneNumbers
+from .conferences import Conferences
+from .connect_apps import ConnectApps, AuthorizedConnectApps
+from .queues import Queues
+from .usage import UsageRecords, UsageTriggers
+from .messages import Messages
+from .media import MediaList
+from .sip import Sip
 
 
 class Account(InstanceResource):
-    """ An Account resource """
+    """ An Account resource
 
-    ACTIVE = "active"
-    SUSPENDED = "suspended"
-    CLOSED = "closed"
+    """
+
+    ACTIVE = "active"        #: A constant representing an active account
+    SUSPENDED = "suspended"  #: A constant representing a suspended account
+    CLOSED = "closed"        #: A constant representing a closed account
 
     subresources = [
         Applications,
@@ -36,15 +39,20 @@ class Account(InstanceResource):
         AuthorizedConnectApps,
         UsageRecords,
         UsageTriggers,
+        MediaList,
+        Messages,
+        Sip,
     ]
 
     def update(self, **kwargs):
         """
+        Update the status of an account.
+
         :param friendly_name: Update the description of this account.
         :param status: Alter the status of this account
 
-        Use :data:`CLOSED` to irreversibly close this account,
-        :data:`SUSPENDED` to temporarily suspend it, or :data:`ACTIVE`
+        Use :const:`CLOSED` to irreversibly close this account,
+        :const:`SUSPENDED` to temporarily suspend it, or :const:`ACTIVE`
         to reactivate it.
         """
         self.update_instance(**kwargs)
