@@ -1,17 +1,15 @@
 import logging
 import os
-import sys
+import platform
 
-from six import integer_types, string_types, binary_type, iteritems, u
-from twilio.compat import urlparse
-from twilio.compat import urlencode
+from six import integer_types, string_types, binary_type, iteritems
+from ...compat import urlparse
+from ...compat import urlencode
 
-import twilio
-from twilio import TwilioException, TwilioRestException
-from twilio.rest.resources import UNSET_TIMEOUT
-from twilio.rest.resources.connection import Connection
-from twilio.rest.resources.imports import parse_qs, httplib2, json
-from twilio.rest.resources.util import transform_params, parse_rfc2822_date
+from ... import __version__, TwilioException, TwilioRestException
+from .connection import Connection
+from .imports import parse_qs, httplib2, json
+from .util import transform_params, parse_rfc2822_date, UNSET_TIMEOUT
 
 
 class Response(object):
@@ -28,6 +26,9 @@ class Response(object):
 
 def get_cert_file():
     """ Get the cert file location or bail """
+    # XXX - this currently fails test coverage because we don't actually go
+    # over the network anywhere. Might be good to have a test that stands up a
+    # local server and authenticates against it.
     try:
         # Apparently __file__ is not available in all places so wrapping this
         # in a try/catch
@@ -114,7 +115,12 @@ def make_twilio_request(method, uri, **kwargs):
         or 500-level response.
     """
     headers = kwargs.get("headers", {})
-    headers["User-Agent"] = "twilio-python/%s" % twilio.__version__
+
+    user_agent = "twilio-python/%s (Python %s)" % (
+        __version__,
+        platform.python_version(),
+    )
+    headers["User-Agent"] = user_agent
     headers["Accept-Charset"] = "utf-8"
 
     if method == "POST" and "Content-Type" not in headers:
@@ -137,38 +143,8 @@ def make_twilio_request(method, uri, **kwargs):
             code = None
             message = resp.content
 
-        def red(msg):
-            return u("\033[31m\033[49m%s\033[0m") % msg
-
-        def white(msg):
-            return u("\033[37m\033[49m%s\033[0m") % msg
-
-        def blue(msg):
-            return u("\033[34m\033[49m%s\033[0m") % msg
-
-        def orange(msg):
-            return u("\033[33m\033[49m%s\033[0m") % msg
-
-        def teal(msg):
-            return u("\033[36m\033[49m%s\033[0m") % msg
-
-        # If it makes sense to print a human readable error message, try to do
-        # it. The one problem is that someone might catch this error and try to
-        # display the message from it to an end user.
-        if hasattr(sys.stderr, 'isatty') and sys.stderr.isatty():
-            msg = red("\nHTTP Error. ")
-            msg += white("Your request was:\n\n")
-            msg += teal("%s %s" % (method, uri))
-            msg += white("\n\nTwilio returned the following information:")
-            msg += blue("\n\n" + str(message) + "\n")
-            if code:
-                msg += white("\nMore information may be available here:\n\n")
-                msg += blue("https://www.twilio.com/docs/errors/%s" % code)
-                msg += "\n\n"
-        else:
-            msg = message
-
-        raise TwilioRestException(resp.status_code, resp.url, msg, code)
+        raise TwilioRestException(status=resp.status_code, method=method,
+                                  uri=resp.url, msg=message, code=code)
 
     return resp
 
@@ -379,7 +355,9 @@ class ListResource(Resource):
         return self.load_instance(entry)
 
     def count(self):
-        """ Get the total number of instances for this resource
+        """ .. deprecated:: 3.6.5
+
+        Get the total number of instances for this resource
 
         Note: this query can be slow if you have many instances.
 
@@ -387,6 +365,7 @@ class ListResource(Resource):
         :rtype: int
         :raises: a :exc:`~twilio.TwilioRestException` if the request fails
 
+
         Example usage:
 
         .. code-block:: python
@@ -440,7 +419,6 @@ class ListResource(Resource):
 
     def __str__(self):
         return '<%s (%s)>' % (self.__class__.__name__, self.count())
-        return '<%s (%s)>' % (self.__class__.__name__, self.count())
 
     def list(self, **kw):
         """Query the list resource for a list of InstanceResources.
