@@ -1,6 +1,6 @@
-from twilio.rest.resources import InstanceResource, ListResource
-from twilio.rest.resources.media import MediaList
-from twilio.rest.resources.util import normalize_dates, parse_date
+from . import InstanceResource, ListResource
+from .media import MediaList
+from .util import normalize_dates, parse_date
 
 
 class Message(InstanceResource):
