@@ -17,7 +17,10 @@ def transform_params(parameters):
     transformed_parameters = {}
 
     for key, value in iteritems(parameters):
-        if value is not None:
+        if isinstance(value, (list, tuple, set)):
+            value = [convert_boolean(param) for param in value]
+            transformed_parameters[format_name(key)] = value
+        elif value is not None:
             transformed_parameters[format_name(key)] = convert_boolean(value)
 
     return transformed_parameters
@@ -46,9 +49,12 @@ def parse_date(d):
 def parse_rfc2822_date(s):
     """
     Parses an RFC 2822 date string and returns a time zone naive datetime
-    object. It is assumed that all dates returned from Twilio are UTC.
+    object. All dates returned from Twilio are UTC.
     """
-    return datetime.datetime(*parsedate(s)[:6])
+    date_tuple = parsedate(s)
+    if date_tuple is None:
+        return None
+    return datetime.datetime(*date_tuple[:6])
 
 
 def convert_boolean(boolean):
@@ -118,3 +124,14 @@ def change_dict_key(d, from_key, to_key):
         d[to_key] = d.pop(from_key)
     except KeyError:
         pass
+
+
+class _UnsetTimeoutKls(object):
+    """ A sentinel for an unset timeout. Defaults to the system timeout. """
+    def __repr__(self):
+        return '<Unset Timeout Value>'
+
+
+# None has special meaning for timeouts, so we use this sigil to indicate
+# that we don't care
+UNSET_TIMEOUT = _UnsetTimeoutKls()
